export declare enum Directions {
    LEFT = "left",
    RIGHT = "right",
    UP = "up",
    DOWN = "down",
    ENTER = "enter",
    UNSPECIFIED = "*"
}
export declare type Direction = `${Directions}`;
export declare enum Orientations {
    VERTICAL = "vertical",
    HORIZONTAL = "horizontal"
}
export declare type Orientation = `${Orientations}`;
export declare type NodeId = string;
export declare type NodeIndex = number;
export declare type NodeIndexRange = [NodeIndex, NodeIndex];
export interface Node {
    id?: NodeId;
    parent?: NodeId;
    index?: NodeIndex;
    indexRange?: NodeIndexRange;
    selectAction?: any;
    isFocusable?: boolean;
    isWrapping?: boolean;
    isStopPropagate?: boolean;
    orientation?: Orientation;
    isIndexAlign?: boolean;
    onLeave?: (leave: Node) => void;
    onEnter?: (enter: Node) => void;
    shouldCancelLeave?: (leave: Node, enter: Node) => boolean;
    onLeaveCancelled?: (currentFocusNode: Node, focusableNode: Node) => void;
    shouldCancelEnter?: (leave: Node, enter: Node) => boolean;
    onEnterCancelled?: (currentFocusNode: Node, focusableNode: Node) => void;
    activeChild?: NodeId;
    children?: NodeTree;
    onSelect?: (node: Node) => void;
    onInactive?: (node: Node) => void;
    onActive?: (node: Node) => void;
    onActiveChildChange?: (event: {
        node: Node;
        leave: Node;
        enter: Node;
    }) => void;
    onBlur?: (node: Node) => void;
    onFocus?: (node: Node) => void;
    onMove?: (event: {
        node: Node;
        leave: Node;
        enter: Node;
        direction: Direction;
        offset: -1 | 1;
    }) => void;
    [name: string]: any;
}
export declare type NodeTree = {
    [id in NodeId]: Node;
};
export declare type OverrideId = string;
export interface Override {
    id: NodeId;
    direction: string;
    target: NodeId;
}
export declare type OverrideTree = {
    [id in OverrideId]: Override;
};
export interface KeyEvent {
    keyCode?: number;
    direction?: Direction;
}
export interface HandleKeyEventOptions {
    forceFocus?: boolean;
}
export interface InsertTreeOptions {
    maintainIndex?: boolean;
}
export interface UnregisterNodeOptions {
    forceRefocus?: boolean;
}
export interface MoveNodeOptions {
    index?: NodeIndex;
    maintainIndex?: boolean;
}
